package com.xingye.atswingtool;

import org.eclipse.jetty.server.*;
import org.eclipse.jetty.server.handler.ErrorHandler;
import org.eclipse.jetty.webapp.WebAppContext;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.net.URL;

public class Application {

    static {
        start();
    }

    private static void start() {
        int port = 10038;
        Server server = new Server();
        HttpConfiguration https_config = new HttpConfiguration();
        https_config.setOutputBufferSize(32768000);
        ServerConnector httpsConnector = new ServerConnector(server,
                new HttpConnectionFactory(https_config));
        httpsConnector.setPort(port);
        httpsConnector.setIdleTimeout(50000);
        server.addConnector(httpsConnector);

        WebAppContext context = new WebAppContext();
        URL url = ClassLoader.getSystemClassLoader().getResource("web2.xml");
        System.out.println(url);

        copyFileToOut(null, "web2.xml");
        context.setDescriptor(".\\web2.xml");
        context.setResourceBase(new File(".").getAbsolutePath());
        context.setContextPath("/atswingtool");
        context.setErrorHandler(new ErrorHandler() {
            @Override
            public void doError(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException {
                System.out.println("error");
            }
        });
        context.setParentLoaderPriority(true);
        server.setHandler(context);
        try {
            server.start();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private static void copyFileToOut(String prefix, String filename) {
        byte[] buffer = new byte[512];
        FileOutputStream fos = null;
        BufferedOutputStream out = null;
        InputStream in = null;
        try {
            in = Application.class.getClassLoader().getResourceAsStream(filename);
            fos = new FileOutputStream(filename);
            out = new BufferedOutputStream(fos);
            while (true) {
                int readed = in.read(buffer);
                if (readed > -1) {
                    out.write(buffer, 0, readed);
                } else {
                    break;
                }
            }
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            buffer = null;
            try {
                if (out != null) {
                    out.close();
                    out = null;
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
            try {
                if (fos != null) {
                    fos.close();
                    fos = null;
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
            try {
                if (in != null) {
                    in.close();
                    in = null;
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

    }
}
